#
# spec file for package ftxui
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         c_lib libftxui5_0_0
Name:           ftxui
Version:        5.0.0
Release:        bp160.1.7
Summary:        A C++ library for terminal based user interfaces
License:        MIT
URL:            https://github.com/ArthurSonzogni/FTXUI
Source:         https://github.com/ArthurSonzogni/FTXUI/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
A C++ library for terminal based user interfaces.

%package -n     %{c_lib}
Summary:        A C++ library for terminal based user interfaces
Group:          System/Libraries
Recommends:     %{name} >= %{version}

%description -n %{c_lib}
A C++ library for terminal based user interfaces.

%package devel
Summary:        Devel files for ftxui
Group:          Development/Libraries/C and C++
Requires:       %{c_lib} = %{version}
Provides:       ftxui

%description devel
Development files for ftxui.

%prep
%autosetup -n FTXUI-%{version}

%build
%cmake -DFTXUI_BUILD_EXAMPLES=OFF \
       -DFTXUI_BUILD_TESTS=OFF \
       -DFTXUI_BUILD_DOCS=OFF \
       -DFTXUI_ENABLE_INSTALL=ON

%install
%cmake_install

%ldconfig_scriptlets -n %{c_lib}

%files -n %{c_lib}
%license LICENSE
%doc CHANGELOG.md README.md
%{_libdir}/libftxui-component.so.5.0.0
%{_libdir}/libftxui-dom.so.5.0.0
%{_libdir}/libftxui-screen.so.5.0.0

%files devel
%license LICENSE
%doc CHANGELOG.md README.md
%{_includedir}/ftxui/
%{_libdir}/cmake/ftxui/
%{_libdir}/libftxui-component.so
%{_libdir}/libftxui-dom.so
%{_libdir}/libftxui-screen.so
%{_libdir}/pkgconfig/ftxui.pc

%changelog
* Mon Aug 21 2023 Michael Vetter <mvetter@suse.com>
- Update to 5.0.0:
  Component:
  * Breaking: MenuDirection enum is renamed Direction
  * Breaking: GaugeDirection enum is renamed Direction
  * Breaking: Direction enum is renamed WidthOrHeight
  * Breaking: Remove ComponentBase copy constructor/assignment.
  * Breaking: MenuOption::entries is renamed MenuOption::entries_option.
  * Breaking: Ref<{Component}Option> becomes {Component}Option in component constructors.
  * Feature: ResizeableSplit now support arbitrary element as a separator.
  * Feature: input is now supporting multiple lines.
  * Feature: input style is now customizeable.
  * Bugfix: Support F1-F5 from OS terminal.
  * Feature: Add struct based constructor:
    + Component Button(ButtonOption options);
    + Component Checkbox(CheckboxOption options);
    + Component Input(InputOption options);
    + Component Menu(MenuOption options);
    + Component MenuEntry(MenuEntryOption options);
    + Component Radiobox(RadioboxOption options);
    + Component Slider(SliderOption<T> options);
    + Component ResizableSplit(ResizableSplitOption options);
  * Feature: Add ScreenInteractive::TrackMouse(false) disable mouse support.
  Dom:
  * Feature: Add hyperlink decorator. For instance:
    auto link = text("Click here") | hyperlink("https://github.com/FTXUI")
    See the OSC 8 page.
    FTXUI support proposed by @aaleino in #662.
  Screen:
  * Breaking: WordBreakProperty becomes a uint8_t enum. This yields a 0.8%%
    performance improvement.
  * Breaking: Remove user defined Pixel constructor and equality operator.
  * Performance: 19%% faster on benchmarks.
  Build:
  * Check version compatibility when using cmake find_package()
  * Add FTXUI_DEV_WARNING options to turn on warnings when building FTXUI
  * Turn OFF by default FTXUI_BUILD_DOCS
  * Turn OFF by default FTXUI_BUILD_EXAMPLE
* Sun May 28 2023 Michael Vetter <mvetter@suse.com>
- Update to 4.1.1:
  * Resolve compile issues in component_fuzzer
* Fri May 19 2023 Michael Vetter <mvetter@suse.com>
- Update to 4.1.0:
  Component:
  * Feature: Support ResizableSplit with customizable separator.
  * Fix: Support arrow keys in application mode
  * Fix: Remove useless new line when using an alternative screen.
  Dom:
  * Feature: Add the dashed style for border and separator:
    See DASHED enum, and separatorDashed(), borderDashed() functions.
  * Feature: Add colored borders.
    See functions: borderStyled(BorderStyle, Color) and borderStyled(Color).
  * Feature: Add LinearGradient. It can be used in color and bgColor.
  * Improvement: Color::Interpolate() uses gamma correction.
  * Fix: Check the graph area is positive.
  Build/Install:
  * Use globally set CMAKE_CXX_STANDARD if it is set.
  * Expose the pkg-config file.
* Sun Apr  2 2023 Michael Vetter <mvetter@suse.com>
- Initial package of ftxui 4.0.0 for openSUSE
